#!/usr/bin/perl 
#############################################################
#	This program goes through the directory named in its
#	first argument. It looks through all non-executable,
#	files to see which ones fit a JPEG or GIF format.
#
#	If no first argument is given, then it uses "." as
#	the directory.
#
#	If an argument of "-r" is given, then the program
#	searches directories recursively.
#
#	Output: a list of HTML statements that give WIDTH and
#	HEIGHT attributes
#
#	Written by:
#		J. David Eisenberg
#		nessus@best.com
#############################################################

sub get_gif_dimensions
{
	my ($fName) = @_;
	my ($width, $height, $buf, $w2, $w1, $h2, $h1);
	$width = $height = 0;

	if (!open(FILE, "<$fName"))
	{
		return (0,0);
	}
	read( FILE, $buf, 3);	# get rid of GIF
	read( FILE, $buf, 3);	# get rid of "87a" or "89a"
	read( FILE, $buf, 4);	# width and height
	($width, $height) = unpack("vv", $buf);
#	($w2, $w1, $h2, $h1) = unpack("CCCC", $buf);
#	$width = $w1 * 256 + $w2;
#	$height = $h1 * 256 + $h2;
	close FILE;
	return ($width, $height);
}

sub get_jpg_dimensions
{
	my ($file_name) = @_;

    my ($width, $height);
	my ($n_read, $ff_byte, $tag_byte, $buf, $result);

	if (!open(FILE, "<$fName"))
	{
		return (0,0);
	}

	$width = $height = 0;

	# skip back to third byte...
	seek( FILE, 2, 0 );
	while (1)
	{
		#
		#	read in four bytes (0xff, tag byte, and 2-byte length)
		#	when the tag byte equals 0xc0, that is the part of the
		#	file which holds the dimensions
		#
		$n_read = read( FILE, $buf, 4);
		last if ($n_read != 4);

		($ff_byte, $tag_byte, $l1, $l2) = unpack("CCCC", $buf);
		last if ($ff_byte != 0xff);

		$len = $l1 * 256 + $l2;

		if ($tag_byte == 0xc0)
		{
			$n_read = read( FILE, $buf, 5 );
			last if ($n_read != 5);

			($tag_byte, $height, $width) = unpack("Cnn", $buf);
#			($infoByte, $h1, $h2, $w1, $w2) = unpack("CCCCC", $buf);
#			$height = $h1 * 256 + $h2;
#			$width = $w1 * 256 + $w2;
			last;
		}
		
		#
		#	if it's not the 0xc0 tag, then skip forwards to next area.
		#	we subtract 2 from the length since it includes the length
		#	bytes, which we've already read.
		#
		$result = seek( FILE, $len-2, 1);
		last if ($result == 0);
	}
	close FILE;
	return ($width, $height);
}			
			

#sub get_dimensions
#{
#	my ($file_name) = $_[0];
#    my ($w, $h) = (0, 0);
#	my (@stats);
#	@stats = stat($file_name);
#			
#	if (! (-x _ ))
#	{
#		# open the file...
#		if (!open( FILE, $file_name))
#		{
#			return (0, 0);
#		}
#		
#		# see what kind of file it might be
#		read( FILE, $signature, 3);
#		if ($signature eq "GIF")
#		{
#			($w,$h) = &get_gif_dimensions( $file_name );
#		}
#		elsif ($signature eq "\xff\xd8\xff")
#		{
#			($w,$h) = &get_jpg_dimensions( $file_name );
#		}
#		return ($w, $h);
#	}
#}

return 1;
