/*******************************************************************************
	ClockApplet.java
	
	Applet that displays a clock face with the time
	
	Inspired by code in _Core Java_ by Gary Cornell and Cay S. Horstmann
	(c) 1996 Sun Microsystems, Inc.
		
		Copyright (c) 1997-1998 J. David Eisenberg
********************************************************************************/

import java.awt.*;
import java.util.*;
import java.applet.Applet;

public class ClockApplet extends Applet
{
	public int hour, minute;

	public void init()
	{
		setBackground( Color.white );
		hour = 0;
		minute = 0;
	}

	public void setTime( int h, int m )
	{
		hour = h % 12;
		minute = m % 60;
		repaint();
	}

	public void paint( Graphics g )
	{
        Font smallFont = new Font("Helvetica", Font.PLAIN, 10 );
        FontMetrics fm;

        int x0, y0, x1, y1, x2, y2, i;
        double angle;
       
	   	if (hour < 0)
		{
			return;
		}
        g.setFont( smallFont );
        fm = g.getFontMetrics();

		g.setColor( Color.white );
		g.fillRect( 0, 0, 100, 100 );

        g.setColor( new Color( 255, 255, 192 ) );
        /* the clock face with the center hand */
		g.fillOval(10, 10, 80, 80);
        g.setColor( Color.black );
        g.drawOval(10, 10, 80, 80);
        g.drawOval( 48, 48, 4, 4);
        
        /* draw the 12 / 3 / 6/ 9 numerals */
        g.setFont( smallFont );
        g.drawString( "12", 50-fm.stringWidth("12")/2, 11+fm.getAscent() );
        g.drawString( "3", 88-fm.stringWidth("3"), 50+fm.getAscent()/2 );
        g.drawString( "6", 50-fm.stringWidth("6")/2, 88 );
        g.drawString( "9", 12, 50+fm.getAscent()/2 );
        
        x0 = 50;
        y0 = 50;

		// the tick marks
		for (i=0; i<12; i++)
		{
			angle = -(i*30) + 90;
			angle = angle * Math.PI / 180.0;
			x1 = (int) (x0 + 37 * (Math.cos( angle ) ));
			y1 = (int) (y0 - 37 * (Math.sin( angle ) ));
			x2 = (int) (x0 + 39 * (Math.cos( angle ) ));
			y2 = (int) (y0 - 39 * (Math.sin( angle ) ));
			g.drawLine( x1,y1, x2, y2 );
		}

        /* draw the hour hand */
        hour %= 12;
        angle = -(hour * 30 + minute/2) + 90;
        angle = angle * (Math.PI / 180.0);

        x1 = (int) (x0 + 28 * (Math.cos( angle ) ));
        y1 = (int) (y0 - 28 * (Math.sin( angle ) ));
        g.drawLine( x0, y0, x1, y1 );
        
        /* and the minute hand */
        angle = -(minute * 6) + 90;
        angle = angle * Math.PI / 180.0;
        x1 = (int) (x0 + 35 * (Math.cos( angle ) ));
        y1 = (int) (y0 - 35 * (Math.sin( angle ) )); 
        g.drawLine( x0, y0, x1, y1 );
	}
}
